@@ -128,7 +128,15 @@ class MultiprocessDomparserResult():
         self.inst = inst
 
     def _call_dom(self, opts):
-        return self.inst._exec_dom_opt(opts).html()
+        start_time = time.time()
+        out = self.inst._exec_dom_opt(opts).html()
+        end_time = time.time()
+        return [out, int((end_time - start_time)*100)/100]
+
+    def save_html(self, file_name='output'):
+        with open(f"{file_name}.html", 'w') as f:
+            f.write(self.html())
+        return self
 
     def show(self):
         display = importlib.import_module("IPython.core.display")
@@ -140,32 +148,41 @@ class MultiprocessDomparserResult():
         chunks = []
 
         index = -1
-        for output_html in output_htmls:
+        for out in output_htmls:
+            output_html = out[0]
+            parsing_time = out[1]
+
             index = index+1
             soup = BeautifulSoup(output_html, features="html.parser")
             body = soup.body
             body_contents = str(body.find_all(recursive=False)[0])
             wrapped_result = f"""
-            <li>
-                <div>
-                    <i>{self.input[index]}</i>
-                </div>
+            <section>
                 <div>
                     <table>
                         <tr>
                             <th>Property</th>
                             <th>Value</th>
                         </tr>
+                        <tr>
+                            <td>Sentence no.</td>
+                            <td>{index+1}</td>
+                        </tr>
                         <tr>
                             <td>Input sentence</td>
                             <td>{self.input[index]}</td>
                         </tr>
+                        <tr>
+                            <td>Parsing time</td>
+                            <td>{parsing_time} sec.</td>
+                        </tr>
                     </table>
                 </div>
+                <br/>
                 <div>
                     {body_contents}
                 </div>
-            </li>
+            </section>
             """
             chunks.append(wrapped_result)
 
@@ -179,9 +196,12 @@ class MultiprocessDomparserResult():
                     <META HTTP-EQUIV="Content-Language" CONTENT="pl">
                 </head>
                 <body>
-                    <ul>
+                    <div>
+                        ENIAM parsed {len(self.input)} sentences.
+                    </div>
+                    <div>
                         {chunks_str}
-                    </ul>
+                    <div>
                 </body>
         """
 
@@ -197,6 +217,11 @@ class DomparserResult():
         for file in self.output_pngs:
             file.seek(0)
 
+    def save_html(self, file_name='output'):
+        with open(f"{file_name}.html", 'w') as f:
+            f.write(self.html())
+        return self
+
     def _replace_all_links(self, html_code):
         for original_file_name in self.file_map:
             entry = self.file_map[original_file_name]
@@ -269,6 +294,11 @@ class SubsyntaxResult():
     def html(self):
         return self.html_conent
 
+    def save_html(self, file_name='output'):
+        with open(f"{file_name}.html", 'w') as f:
+            f.write(self.html())
+        return self
+
 
 class Eniam():
 
